@@ -22,25 +22,46 @@ join_url <- function(url, endpoint) {
 #'
 #' @importFrom httr RETRY
 #' @keywords internal
-do_request <- function(url, params, timeout_seconds = 30) {
+do_request <- function(url, params, timeout_seconds) {
   # don't retry in case of certain status codes
-  res <- httr::RETRY("GET",
-    url = url,
-    query = params,
-    terminate_on = c(400, 401, 403, 405, 414, 500),
-    http_headers,
-    httr::authenticate("epidata", get_auth_key()),
-    httr::timeout(timeout_seconds)
-  )
-  if (res$status_code == 414) {
-    res <- httr::RETRY("POST",
+  key <- get_api_key()
+  if (key != "") {
+    res <- httr::RETRY("GET",
       url = url,
-      body = params,
-      encode = "form",
+      query = params,
       terminate_on = c(400, 401, 403, 405, 414, 500),
       http_headers,
-      httr::authenticate("epidata", get_auth_key())
+      httr::authenticate("epidata", get_api_key()),
+      httr::timeout(timeout_seconds)
     )
+  } else {
+    res <- httr::RETRY("GET",
+      url = url,
+      query = params,
+      terminate_on = c(400, 401, 403, 405, 414, 500),
+      http_headers,
+      httr::timeout(timeout_seconds)
+    )
+  }
+  if (res$status_code == 414) {
+    if (key != "") {
+      res <- httr::RETRY("POST",
+        url = url,
+        body = params,
+        encode = "form",
+        terminate_on = c(400, 401, 403, 405, 414, 500),
+        http_headers,
+        httr::authenticate("epidata", get_api_key())
+      )
+    } else {
+      res <- httr::RETRY("POST",
+        url = url,
+        body = params,
+        encode = "form",
+        terminate_on = c(400, 401, 403, 405, 414, 500),
+        http_headers
+      )
+    }
   }
   res
 }
